function [residual, g1, g2, g3] = model_solution_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 92, 1);

%
% Model equations
%

T15 = (1-params(1))*(1-params(1)*params(2))/params(1);
T37 = params(21)*params(41)^(1-params(11));
T46 = params(20)*params(41)^(params(11)-1);
T85 = params(23)/params(11)*params(13)*params(37)/(params(87)*params(39));
T93 = params(23)/params(11)*params(12)/(params(87)*params(38));
T170 = params(77)/(1+params(77));
T172 = 1/params(113);
T177 = (params(113)-1)/params(113);
T187 = params(78)/(1+params(78));
T189 = 1/params(112);
T195 = (T189-T172)*y(64);
T204 = params(79)/(1+params(79));
T220 = params(117)^((-(params(113)-1))/params(113));
T224 = (params(116)*params(95))^T177;
T227 = params(119)^T177;
T237 = (params(119)/params(114))^((-(params(112)-1))/params(112));
T239 = (params(112)-1)/params(112);
T240 = params(101)^T239;
T244 = params(102)^T239;
T269 = params(81)/(1+params(81));
T282 = params(82)/(1+params(82));
T297 = params(83)/(1+params(83));
T309 = params(118)^((-(params(113)-1))/params(113));
T312 = (params(116)*params(96))^T177;
T315 = params(120)^T177;
T321 = (params(120)/params(114))^((-(params(112)-1))/params(112));
T324 = params(111)*params(103)^T239;
T329 = (1-params(111))*params(104)^T239;
T357 = params(87)*params(38)^params(11);
T368 = params(10)/(1-params(10))*params(37)^params(11);
T386 = params(12)*params(38)^(params(11)-1);
T409 = params(95)*((1+params(93))/params(34)-1);
T437 = params(96)*((1+params(94))/params(34)-1);
T471 = (1-params(10))/params(10)*params(102)/params(37);
T492 = 1/params(135);
T517 = 1/params(141);
T636 = params(84)/(params(87)*params(38));
T645 = (1-params(105))*params(8)*params(91)/(params(87)*params(38));
T662 = params(85)/(params(87)*params(39)/params(37));
T674 = (1-params(106))*params(16)*params(92)/(params(87)*params(39)/params(37));
lhs =y(1);
rhs =T15*y(11)+y(1)*params(2)+y(48);
residual(1)= lhs-rhs;
lhs =y(2);
rhs =T15*y(12)+params(2)*y(2)+y(49);
residual(2)= lhs-rhs;
lhs =y(3);
rhs =y(1);
residual(3)= lhs-rhs;
lhs =y(4);
rhs =y(2)+y(14)-y(14);
residual(4)= lhs-rhs;
lhs =y(13);
rhs =params(128)*y(20)+params(129)*y(21)+params(130)*y(22)+params(131)*y(26)+params(144)*y(52)+params(145)*y(53)+T85*y(54)-T93*y(8);
residual(5)= lhs-rhs;
lhs =y(15);
rhs =y(13)*(-(T37/(T37+params(20))));
residual(6)= lhs-rhs;
lhs =y(16);
rhs =y(13)*T46/(params(21)+T46);
residual(7)= lhs-rhs;
lhs =y(14);
rhs =y(13)*params(22);
residual(8)= lhs-rhs;
lhs =y(3)+y(14)-y(14);
rhs =y(4)+y(5)-y(5);
residual(9)= lhs-rhs;
lhs =0;
rhs =y(3)+y(58);
residual(10)= lhs-rhs;
lhs =0;
rhs =y(3)-y(17)+y(9);
residual(11)= lhs-rhs;
lhs =0;
rhs =y(5)+y(3)-y(18)-y(5)+y(10);
residual(12)= lhs-rhs;
lhs =0;
rhs =y(4)+y(60);
residual(13)= lhs-rhs;
lhs =0;
rhs =y(4)-y(18)+y(61);
residual(14)= lhs-rhs;
lhs =0;
rhs =y(5)+y(4)-y(17)-y(5)+y(62);
residual(15)= lhs-rhs;
lhs =y(57)+y(22)*params(3)-y(55);
rhs =y(14)+y(59)+y(26)*params(3)-y(56);
residual(16)= lhs-rhs;
lhs =y(8);
rhs =y(22)*params(28)+(1-params(28))*y(63);
residual(17)= lhs-rhs;
lhs =y(57);
rhs =params(76)/(1+params(76))*(y(8)-y(22));
residual(18)= lhs-rhs;
lhs =y(58);
rhs =T170*(y(8)-T172*y(23)+T177*y(67)-y(63)*T177);
residual(19)= lhs-rhs;
lhs =y(9);
rhs =T187*(y(8)-T189*y(24)+T195+y(68)-y(63)*T177);
residual(20)= lhs-rhs;
lhs =y(10);
rhs =T204*(T195+y(8)-T189*y(25)-y(68)*params(111)/(1-params(111))-y(63)*T177);
residual(21)= lhs-rhs;
lhs =y(63);
rhs =T220*(y(23)*T224+y(64)*T227);
residual(22)= lhs-rhs;
lhs =y(64);
rhs =T237*(y(24)*params(111)*T240+y(25)*(1-params(111))*T244+y(68)*params(111)*params(112)/(params(112)-1)*(T240-T244));
residual(23)= lhs-rhs;
lhs =y(54);
rhs =y(26)*params(28)+(1-params(28))*y(65);
residual(24)= lhs-rhs;
lhs =y(59);
rhs =params(80)/(1+params(80))*(y(54)-y(26));
residual(25)= lhs-rhs;
lhs =y(60);
rhs =T269*(y(54)-T172*y(27)+T177*y(70)-T177*y(65));
residual(26)= lhs-rhs;
lhs =y(61);
rhs =T282*(y(54)-T189*y(28)+(T189-T172)*y(66)+T239*y(72)-T177*y(65));
residual(27)= lhs-rhs;
lhs =y(62);
rhs =T297*((T189-T172)*y(66)+y(54)-T189*y(29)+T239*y(71)-T177*y(65));
residual(28)= lhs-rhs;
lhs =y(65);
rhs =T309*(y(27)*T312+y(66)*T315);
residual(29)= lhs-rhs;
lhs =y(66);
rhs =T321*(T324*(y(28)+y(72))+T329*(y(29)+y(71)));
residual(30)= lhs-rhs;
lhs =y(11);
rhs =y(57)+y(22)*params(3)+y(20)*params(4)-(1+params(4))*y(44)-y(15)-y(55);
residual(31)= lhs-rhs;
lhs =y(12);
rhs =y(59)+y(14)+y(26)*params(3)+y(21)*params(4)-(1+params(4))*y(45)-y(16)-y(56);
residual(32)= lhs-rhs;
lhs =T357*(y(20)+params(11)*y(15));
rhs =y(22)*params(20)*params(86)+params(21)*params(86)*T368*(y(26)+params(11)*y(14))+params(21)*T368*params(89)*(y(53)+params(11)*y(14))+y(52)*params(20)*params(88)+T386*(y(8)+(params(11)-1)*y(15));
residual(33)= lhs-rhs;
lhs =params(91)*y(34)+params(84)*y(36)+y(23)*params(95)*(1-1/params(34))+T409*(y(23)-y(3))+y(17)*params(95)*(1+params(93))/params(34);
rhs =params(91)*(1+params(93))*(y(34)+y(17)-y(3))+y(52)*params(88);
residual(34)= lhs-rhs;
lhs =params(92)*y(35)+params(85)*y(37)+y(27)*params(96)*(1-1/params(34))+T437*(y(27)-y(4))+y(18)*params(96)*(1+params(94))/params(34);
rhs =params(92)*(1+params(94))*(y(35)+y(18)-y(4))+y(53)*params(89);
residual(35)= lhs-rhs;
lhs =y(23)+y(73);
rhs =y(32);
residual(36)= lhs-rhs;
lhs =y(27);
rhs =y(33);
residual(37)= lhs-rhs;
lhs =params(91)*y(34);
rhs =y(32)*params(35)+y(24)*params(101)+params(37)*params(104)*params(10)/(1-params(10))*(y(14)+y(29));
residual(38)= lhs-rhs;
lhs =params(92)*y(35);
rhs =y(33)*params(36)+T471*(y(25)-y(14))+y(28)*params(103);
residual(39)= lhs-rhs;
lhs =y(7);
rhs =y(18)-y(17);
residual(40)= lhs-rhs;
lhs =y(6);
rhs =y(18)-y(17);
residual(41)= lhs-rhs;
lhs =y(19);
rhs =y(17)-y(18);
residual(42)= lhs-rhs;
residual(43) = y(92);
residual(44) = y(91);
lhs =y(38);
rhs =T492*(y(55)+(1+params(4))*y(44)-y(21)*params(136)-y(26)*params(137)-y(52)*params(150)-y(53)*params(151)-y(57)-y(8)*params(123)-y(54)*params(124));
residual(45)= lhs-rhs;
lhs =y(39);
rhs =T517*(y(56)+(1+params(4))*y(45)-y(20)*params(142)-y(22)*params(143)-y(52)*params(152)-y(53)*params(153)-y(59)-y(8)*params(125)-y(54)*params(126));
residual(46)= lhs-rhs;
lhs =y(40);
rhs =y(20)-y(38);
residual(47)= lhs-rhs;
lhs =y(41);
rhs =y(21)-y(39);
residual(48)= lhs-rhs;
lhs =y(30);
rhs =y(34)-y(15)-y(20);
residual(49)= lhs-rhs;
lhs =y(31);
rhs =y(14)+y(35)-y(16)-y(21);
residual(50)= lhs-rhs;
lhs =y(77);
rhs =y(36)-y(15)-y(20);
residual(51)= lhs-rhs;
residual(52) = y(42);
lhs =(params(91)-params(35))*y(43);
rhs =params(91)*y(34)-y(32)*params(35);
residual(53)= lhs-rhs;
lhs =y(87);
rhs =y(17)-y(3);
residual(54)= lhs-rhs;
lhs =y(88);
rhs =y(18)-y(4);
residual(55)= lhs-rhs;
lhs =y(76);
rhs =y(87)-y(88);
residual(56)= lhs-rhs;
lhs =y(74);
rhs =y(25)-y(15)-y(20);
residual(57)= lhs-rhs;
lhs =y(75);
rhs =y(17)-y(9);
residual(58)= lhs-rhs;
lhs =y(80);
rhs =y(18)-y(61);
residual(59)= lhs-rhs;
lhs =y(81);
rhs =y(75)-y(80);
residual(60)= lhs-rhs;
residual(61) = y(82);
residual(62) = y(83);
residual(63) = y(84);
residual(64) = y(85);
residual(65) = y(86);
residual(66) = y(89);
residual(67) = y(90);
lhs =y(78);
rhs =y(82)-y(84);
residual(68)= lhs-rhs;
lhs =y(79);
rhs =y(83)-y(85);
residual(69)= lhs-rhs;
lhs =y(17);
rhs =y(17)*params(5)+y(3)*(1-params(5))*params(6)+y(40)*(1-params(5))*params(7)+y(46);
residual(70)= lhs-rhs;
lhs =y(18);
rhs =y(18)*params(5)+y(4)*(1-params(5))*params(14)+y(41)*(1-params(5))*params(15)+y(35)*(1-params(5))*params(109)+y(47);
residual(71)= lhs-rhs;
lhs =(y(36)-y(15)-y(20))*T636;
rhs =(y(36)-y(15)-y(20))*T636*params(105)+(y(34)-y(15)-y(20))*T645+y(20)*(1-params(105))*params(9)+y(52)*params(88)*(1-params(105))*params(107)+y(50);
residual(72)= lhs-rhs;
lhs =T662*(y(14)+y(37)-y(16)-y(21));
rhs =(y(14)+y(37)-y(16)-y(21))*T662*params(106)+T674*(y(14)+y(35)-y(16)-y(21))+y(21)*(1-params(106))*params(17)+y(53)*params(89)*(1-params(106))*params(108)+y(51);
residual(73)= lhs-rhs;
lhs =y(44);
rhs =y(44)*params(42)+y(45)*params(44)+x(1);
residual(74)= lhs-rhs;
lhs =y(45);
rhs =y(45)*params(43)+y(44)*params(44)+x(2);
residual(75)= lhs-rhs;
lhs =y(46);
rhs =y(46)*params(45)+y(47)*params(47)+x(3);
residual(76)= lhs-rhs;
lhs =y(47);
rhs =y(47)*params(46)+y(46)*params(47)+x(4);
residual(77)= lhs-rhs;
residual(78) = y(48);
residual(79) = y(49);
lhs =y(50);
rhs =y(50)*params(51)+y(51)*params(53)+x(5);
residual(80)= lhs-rhs;
lhs =y(51);
rhs =y(51)*params(52)+y(50)*params(53)+x(6);
residual(81)= lhs-rhs;
residual(82) = y(52);
residual(83) = y(53);
residual(84) = y(55);
residual(85) = y(56);
residual(86) = y(73);
residual(87) = y(67);
residual(88) = y(68);
residual(89) = y(69);
residual(90) = y(70);
residual(91) = y(71);
residual(92) = y(72);
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(92, 92);

  %
  % Jacobian matrix
  %

T788 = (-(T636*params(105)))-T645;
  g1(1,1)=1-params(2);
  g1(1,11)=(-T15);
  g1(1,48)=(-1);
  g1(2,2)=1-params(2);
  g1(2,12)=(-T15);
  g1(2,49)=(-1);
  g1(3,1)=(-1);
  g1(3,3)=1;
  g1(4,2)=(-1);
  g1(4,4)=1;
  g1(5,8)=T93;
  g1(5,13)=1;
  g1(5,20)=(-params(128));
  g1(5,21)=(-params(129));
  g1(5,22)=(-params(130));
  g1(5,26)=(-params(131));
  g1(5,52)=(-params(144));
  g1(5,53)=(-params(145));
  g1(5,54)=(-T85);
  g1(6,13)=T37/(T37+params(20));
  g1(6,15)=1;
  g1(7,13)=(-(T46/(params(21)+T46)));
  g1(7,16)=1;
  g1(8,13)=(-params(22));
  g1(8,14)=1;
  g1(9,3)=1;
  g1(9,4)=(-1);
  g1(10,3)=(-1);
  g1(10,58)=(-1);
  g1(11,3)=(-1);
  g1(11,9)=(-1);
  g1(11,17)=1;
  g1(12,3)=(-1);
  g1(12,10)=(-1);
  g1(12,18)=1;
  g1(13,4)=(-1);
  g1(13,60)=(-1);
  g1(14,4)=(-1);
  g1(14,18)=1;
  g1(14,61)=(-1);
  g1(15,4)=(-1);
  g1(15,17)=1;
  g1(15,62)=(-1);
  g1(16,14)=(-1);
  g1(16,22)=params(3);
  g1(16,26)=(-params(3));
  g1(16,55)=(-1);
  g1(16,56)=1;
  g1(16,57)=1;
  g1(16,59)=(-1);
  g1(17,8)=1;
  g1(17,22)=(-params(28));
  g1(17,63)=(-(1-params(28)));
  g1(18,8)=(-(params(76)/(1+params(76))));
  g1(18,22)=params(76)/(1+params(76));
  g1(18,57)=1;
  g1(19,8)=(-T170);
  g1(19,23)=(-(T170*(-T172)));
  g1(19,58)=1;
  g1(19,63)=(-(T170*(-T177)));
  g1(19,67)=(-(T170*T177));
  g1(20,8)=(-T187);
  g1(20,9)=1;
  g1(20,24)=(-(T187*(-T189)));
  g1(20,63)=(-(T187*(-T177)));
  g1(20,64)=(-(T187*(T189-T172)));
  g1(20,68)=(-T187);
  g1(21,8)=(-T204);
  g1(21,10)=1;
  g1(21,25)=(-(T204*(-T189)));
  g1(21,63)=(-(T204*(-T177)));
  g1(21,64)=(-((T189-T172)*T204));
  g1(21,68)=(-(T204*(-(params(111)/(1-params(111))))));
  g1(22,23)=(-(T220*T224));
  g1(22,63)=1;
  g1(22,64)=(-(T220*T227));
  g1(23,24)=(-(T237*params(111)*T240));
  g1(23,25)=(-(T237*(1-params(111))*T244));
  g1(23,64)=1;
  g1(23,68)=(-(T237*params(111)*params(112)/(params(112)-1)*(T240-T244)));
  g1(24,26)=(-params(28));
  g1(24,54)=1;
  g1(24,65)=(-(1-params(28)));
  g1(25,26)=params(80)/(1+params(80));
  g1(25,54)=(-(params(80)/(1+params(80))));
  g1(25,59)=1;
  g1(26,27)=(-(T269*(-T172)));
  g1(26,54)=(-T269);
  g1(26,60)=1;
  g1(26,65)=(-(T269*(-T177)));
  g1(26,70)=(-(T177*T269));
  g1(27,28)=(-(T282*(-T189)));
  g1(27,54)=(-T282);
  g1(27,61)=1;
  g1(27,65)=(-(T282*(-T177)));
  g1(27,66)=(-((T189-T172)*T282));
  g1(27,72)=(-(T239*T282));
  g1(28,29)=(-(T297*(-T189)));
  g1(28,54)=(-T297);
  g1(28,62)=1;
  g1(28,65)=(-(T297*(-T177)));
  g1(28,66)=(-((T189-T172)*T297));
  g1(28,71)=(-(T239*T297));
  g1(29,27)=(-(T309*T312));
  g1(29,65)=1;
  g1(29,66)=(-(T309*T315));
  g1(30,28)=(-(T321*T324));
  g1(30,29)=(-(T321*T329));
  g1(30,66)=1;
  g1(30,71)=(-(T321*T329));
  g1(30,72)=(-(T321*T324));
  g1(31,11)=1;
  g1(31,15)=1;
  g1(31,20)=(-params(4));
  g1(31,22)=(-params(3));
  g1(31,44)=1+params(4);
  g1(31,55)=1;
  g1(31,57)=(-1);
  g1(32,12)=1;
  g1(32,14)=(-1);
  g1(32,16)=1;
  g1(32,21)=(-params(4));
  g1(32,26)=(-params(3));
  g1(32,45)=1+params(4);
  g1(32,56)=1;
  g1(32,59)=(-1);
  g1(33,8)=(-T386);
  g1(33,14)=(-(params(11)*params(21)*params(86)*T368+params(11)*params(21)*T368*params(89)));
  g1(33,15)=params(11)*T357-(params(11)-1)*T386;
  g1(33,20)=T357;
  g1(33,22)=(-(params(20)*params(86)));
  g1(33,26)=(-(params(21)*params(86)*T368));
  g1(33,52)=(-(params(20)*params(88)));
  g1(33,53)=(-(params(21)*T368*params(89)));
  g1(34,3)=(-T409)-(-(params(91)*(1+params(93))));
  g1(34,17)=params(95)*(1+params(93))/params(34)-params(91)*(1+params(93));
  g1(34,23)=params(95)*(1-1/params(34))+T409;
  g1(34,34)=params(91)-params(91)*(1+params(93));
  g1(34,36)=params(84);
  g1(34,52)=(-params(88));
  g1(35,4)=(-T437)-(-(params(92)*(1+params(94))));
  g1(35,18)=params(96)*(1+params(94))/params(34)-params(92)*(1+params(94));
  g1(35,27)=params(96)*(1-1/params(34))+T437;
  g1(35,35)=params(92)-params(92)*(1+params(94));
  g1(35,37)=params(85);
  g1(35,53)=(-params(89));
  g1(36,23)=1;
  g1(36,32)=(-1);
  g1(36,73)=1;
  g1(37,27)=1;
  g1(37,33)=(-1);
  g1(38,14)=(-(params(37)*params(104)*params(10)/(1-params(10))));
  g1(38,24)=(-params(101));
  g1(38,29)=(-(params(37)*params(104)*params(10)/(1-params(10))));
  g1(38,32)=(-params(35));
  g1(38,34)=params(91);
  g1(39,14)=T471;
  g1(39,25)=(-T471);
  g1(39,28)=(-params(103));
  g1(39,33)=(-params(36));
  g1(39,35)=params(92);
  g1(40,7)=1;
  g1(40,17)=1;
  g1(40,18)=(-1);
  g1(41,6)=1;
  g1(41,17)=1;
  g1(41,18)=(-1);
  g1(42,17)=(-1);
  g1(42,18)=1;
  g1(42,19)=1;
  g1(43,92)=1;
  g1(44,91)=1;
  g1(45,8)=(-(T492*(-params(123))));
  g1(45,21)=(-(T492*(-params(136))));
  g1(45,26)=(-(T492*(-params(137))));
  g1(45,38)=1;
  g1(45,44)=(-((1+params(4))*T492));
  g1(45,52)=(-(T492*(-params(150))));
  g1(45,53)=(-(T492*(-params(151))));
  g1(45,54)=(-(T492*(-params(124))));
  g1(45,55)=(-T492);
  g1(45,57)=T492;
  g1(46,8)=(-(T517*(-params(125))));
  g1(46,20)=(-(T517*(-params(142))));
  g1(46,22)=(-(T517*(-params(143))));
  g1(46,39)=1;
  g1(46,45)=(-((1+params(4))*T517));
  g1(46,52)=(-(T517*(-params(152))));
  g1(46,53)=(-(T517*(-params(153))));
  g1(46,54)=(-(T517*(-params(126))));
  g1(46,56)=(-T517);
  g1(46,59)=T517;
  g1(47,20)=(-1);
  g1(47,38)=1;
  g1(47,40)=1;
  g1(48,21)=(-1);
  g1(48,39)=1;
  g1(48,41)=1;
  g1(49,15)=1;
  g1(49,20)=1;
  g1(49,30)=1;
  g1(49,34)=(-1);
  g1(50,14)=(-1);
  g1(50,16)=1;
  g1(50,21)=1;
  g1(50,31)=1;
  g1(50,35)=(-1);
  g1(51,15)=1;
  g1(51,20)=1;
  g1(51,36)=(-1);
  g1(51,77)=1;
  g1(52,42)=1;
  g1(53,32)=params(35);
  g1(53,34)=(-params(91));
  g1(53,43)=params(91)-params(35);
  g1(54,3)=1;
  g1(54,17)=(-1);
  g1(54,87)=1;
  g1(55,4)=1;
  g1(55,18)=(-1);
  g1(55,88)=1;
  g1(56,76)=1;
  g1(56,87)=(-1);
  g1(56,88)=1;
  g1(57,15)=1;
  g1(57,20)=1;
  g1(57,25)=(-1);
  g1(57,74)=1;
  g1(58,9)=1;
  g1(58,17)=(-1);
  g1(58,75)=1;
  g1(59,18)=(-1);
  g1(59,61)=1;
  g1(59,80)=1;
  g1(60,75)=(-1);
  g1(60,80)=1;
  g1(60,81)=1;
  g1(61,82)=1;
  g1(62,83)=1;
  g1(63,84)=1;
  g1(64,85)=1;
  g1(65,86)=1;
  g1(66,89)=1;
  g1(67,90)=1;
  g1(68,78)=1;
  g1(68,82)=(-1);
  g1(68,84)=1;
  g1(69,79)=1;
  g1(69,83)=(-1);
  g1(69,85)=1;
  g1(70,3)=(-((1-params(5))*params(6)));
  g1(70,17)=1-params(5);
  g1(70,40)=(-((1-params(5))*params(7)));
  g1(70,46)=(-1);
  g1(71,4)=(-((1-params(5))*params(14)));
  g1(71,18)=1-params(5);
  g1(71,35)=(-((1-params(5))*params(109)));
  g1(71,41)=(-((1-params(5))*params(15)));
  g1(71,47)=(-1);
  g1(72,15)=(-T636)-T788;
  g1(72,20)=(-T636)-((1-params(105))*params(9)+T788);
  g1(72,34)=(-T645);
  g1(72,36)=T636-T636*params(105);
  g1(72,50)=(-1);
  g1(72,52)=(-(params(88)*(1-params(105))*params(107)));
  g1(73,14)=T662-(T662*params(106)+T674);
  g1(73,16)=(-T662)-((-(T662*params(106)))-T674);
  g1(73,21)=(-T662)-((1-params(106))*params(17)+(-(T662*params(106)))-T674);
  g1(73,35)=(-T674);
  g1(73,37)=T662-T662*params(106);
  g1(73,51)=(-1);
  g1(73,53)=(-(params(89)*(1-params(106))*params(108)));
  g1(74,44)=1-params(42);
  g1(74,45)=(-params(44));
  g1(75,44)=(-params(44));
  g1(75,45)=1-params(43);
  g1(76,46)=1-params(45);
  g1(76,47)=(-params(47));
  g1(77,46)=(-params(47));
  g1(77,47)=1-params(46);
  g1(78,48)=1;
  g1(79,49)=1;
  g1(80,50)=1-params(51);
  g1(80,51)=(-params(53));
  g1(81,50)=(-params(53));
  g1(81,51)=1-params(52);
  g1(82,52)=1;
  g1(83,53)=1;
  g1(84,55)=1;
  g1(85,56)=1;
  g1(86,73)=1;
  g1(87,67)=1;
  g1(88,68)=1;
  g1(89,69)=1;
  g1(90,70)=1;
  g1(91,71)=1;
  g1(92,72)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],92,8464);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],92,778688);
end
end
end
end
