insheet using "stata_data.csv"

forvalues X = 1/180{

destring sdiff`X', replace ignore("NaN")
destring sj`X', replace ignore("NaN")
destring deltas`X', replace ignore("NaN")
destring idiff_prof`X', replace ignore("NaN")
}

destring idiff, replace ignore("NaN") 
destring debt, replace ignore("NaN")
destring cp, replace ignore("NaN")
destring vix, replace ignore("NaN")
destring intdebt, replace ignore("NaN")
destring yield_sl_us, replace ignore("NaN")
destring yield_sl_int, replace ignore("NaN")
destring vol12m, replace ignore("NaN")
destring vol12mint, replace ignore("NaN")
destring nfa_gdp, replace ignore("NaN")
destring aaa, replace ignore("NaN") 
destring baa, replace ignore("NaN") 
destring treasury, replace ignore("NaN") 

tsset countryid time

* Generate variable to denote end of sample for benchmark results (end of 2007)
gen pre2008 =. 
replace pre2008 = 1 if time < 8349
gen idiff_pre2008 = idiff*pre2008

* Sample of currencies with long time series (no EUR-legacy except for Germany)
gen longs = .
replace longs = 1 if countryid == 193
replace longs = 1 if countryid == 156
replace longs = 1 if countryid == 128
replace longs = 1 if countryid == 134
replace longs = 1 if countryid == 158
replace longs = 1 if countryid == 142
replace longs = 1 if countryid == 196
replace longs = 1 if countryid == 144
replace longs = 1 if countryid == 146
replace longs = 1 if countryid == 112

gen idiff_longs = idiff*longs
*Also match availability of Commercial paper and International debt data -- i.e. start in 1991
replace idiff_longs =. if cp ==.   
replace idiff_longs =. if intdebt ==.   
replace idiff_longs =. if vix ==.   

gen idiff_longs_pre2008 = idiff_longs*pre2008

gen baa_treasury = baa - treasury
gen aaa_treasury = aaa - treasury
gen baa_treasury_pre2008 = baa_treasury*pre2008
gen aaa_treasury_pre2008 = aaa_treasury*pre2008

* Regression coefficients for Figures 1 and 2
postfile betas_se bk bk_se gammak gammak_se dgammak dgammak_se rhok rhok_se using betas_se_file, replace

forvalues X = 1/180{

xtscc sdiff`X' idiff_pre2008, fe ase 
scalar define bk = _b[idiff_pre2008]
scalar define bk_se = _se[idiff_pre2008]

* The second regression involves increasing the overlapping window structure of LHS variable. utilize expanding window of lags for conservative SE
scalar define x1 = (1+floor(`X'/10))*5 + floor(0.5*mod(`X',10)) 

xtscc sj`X' idiff_pre2008, fe ase lag(`=x1')
scalar define gammak = _b[idiff_pre2008]
scalar define gammak_se = _se[idiff_pre2008]

xtscc deltas`X' idiff_pre2008, fe ase 
scalar define dgammak = _b[idiff_pre2008]
scalar define dgammak_se = _se[idiff_pre2008]

xtscc idiff_prof`X' idiff_pre2008, fe ase
scalar define rhok = _b[idiff_pre2008]
scalar define rhok_se = _se[idiff_pre2008]


post betas_se (bk) (bk_se) (gammak) (gammak_se) (dgammak) (dgammak_se) (rhok) (rhok_se) 

}

postclose betas_se

preserve
use betas_se_file, clear
outsheet using betas_se.csv , comma

****** Regressions for Table 3
xtscc sdiff1 idiff_longs_pre2008, fe ase
xtscc sdiff1 idiff_longs_pre2008 debt intdebt, fe ase
xtscc sdiff1 idiff_longs_pre2008 debt intdebt cp, fe ase
xtscc sdiff1 idiff_longs_pre2008 debt intdebt cp vol12m vol12mint yield_sl_us yield_sl_int, fe ase
xtscc sdiff1 idiff_longs_pre2008 debt intdebt cp vol12m vol12mint yield_sl_us yield_sl_int nfa_gdp vix, fe ase

****** Regressions for Table 4
* AAA-Treasury convenience yield proxy calculation
xtscc aaa_treasury_pre2008 debt cp vol12m yield_sl_us, fe ase
scalar define b_debt = _b[debt]
scalar define b_cp = _b[cp]

gen conv_yield_gdpaaa_pre2008 = b_debt*debt + b_cp*cp
replace conv_yield_gdpaaa_pre2008 = conv_yield_gdpaaa_pre2008*longs*pre2008
egen cy_gdpaaa_sd_pre2008 = sd(conv_yield_gdpaaa_pre2008)
scalar cy_gdpaaa_sd_pre2008 = cy_gdpaaa_sd_pre2008[1]
replace conv_yield_gdpaaa_pre2008 = conv_yield_gdpaaa_pre2008/cy_gdpaaa_sd_pre2008


* regressions for columns (1)-(3)
xtscc sdiff1 conv_yield_gdpaaa_pre2008, fe ase
xtscc sdiff1 idiff_longs_pre2008 conv_yield_gdpaaa_pre2008, fe ase
xtscc sdiff1 idiff_longs_pre2008 conv_yield_gdpaaa_pre2008 nfa_gdp vix, fe ase

*BAA-Treasury convenience yield proxy calculation
xtscc baa_treasury_pre2008 debt cp vol12m yield_sl_us, fe ase
scalar define b_debt = _b[debt]
scalar define b_cp = _b[cp]

gen conv_yield_gdppre2008 = b_debt*debt + b_cp*cp
replace conv_yield_gdppre2008 = conv_yield_gdppre2008*longs*pre2008
egen cy_gdp_sd = sd(conv_yield_gdppre2008)
scalar cy_gdp_sd = cy_gdp_sd[1]
replace conv_yield_gdppre2008 = conv_yield_gdppre2008/cy_gdp_sd

* regressions for columns (4)-(6)
xtscc sdiff1 conv_yield_gdppre2008, fe ase
xtscc sdiff1 idiff_longs_pre2008 conv_yield_gdppre2008, fe ase
xtscc sdiff1 idiff_longs_pre2008 conv_yield_gdppre2008 nfa_gdp vix, fe ase


* Regression coefficients for Figures 10
postfile convy_betas aaak aaak_se baak baak_se using betas_se_file, replace

forvalues X = 1/100{

xtscc sdiff`X' idiff_longs_pre2008 conv_yield_gdpaaa_pre2008 nfa_gdp vix, fe ase
scalar define aaak = _b[conv_yield_gdpaaa_pre2008]
scalar define aaak_se = _se[conv_yield_gdpaaa_pre2008]
		
xtscc sdiff`X' idiff_longs_pre2008 conv_yield_gdppre2008 nfa_gdp vix, fe ase
scalar define baak = _b[conv_yield_gdppre2008]
scalar define baak_se = _se[conv_yield_gdppre2008]

post convy_betas (aaak) (aaak_se) (baak) (baak_se)

}

postclose convy_betas

preserve
use betas_se_file, clear
outsheet using convy_betas.csv , comma


*Numbers for in-text discussion in Section 6
xtscc sdiff1 idiff_longs_pre2008, fe ase
scalar define b_idiff = _b[idiff_longs_pre2008]

gen lambda_hat = b_idiff*idiff_longs_pre2008
xtscc lambda_hat debt intdebt cp, fe ase
